@@ -1,9 +1,9 @@
 from .dualize import dualize_protected, dualize_public, dualize_service, dualize_user
 from .protected import (
+    api_service_router,
     optional_principal_router,
     protected_router,
     roles_router,
-    service_router,
     user_router,
 )
 from .public import public_router
@@ -19,6 +19,6 @@ __all__ = [
     "protected_router",
     "optional_principal_router",
     "user_router",
-    "service_router",
+    "api_service_router",
     "roles_router",
 ]
