@@ -16,7 +16,7 @@ from svc_infra.api.fastapi.middleware.errors.catchall import CatchAllExceptionMi
 from svc_infra.api.fastapi.middleware.errors.error_handlers import register_error_handlers
 from svc_infra.api.fastapi.models import APIVersionSpec, ServiceInfo
 from svc_infra.api.fastapi.routers import register_all_routers
-from svc_infra.app.env import CURRENT_ENVIRONMENT, DEV_ENV, LOCAL_ENV
+from svc_infra.app.env import CURRENT_ENVIRONMENT
 
 logger = logging.getLogger(__name__)
 
@@ -133,14 +133,13 @@ def setup_service_api(
     """
     parent = FastAPI(
         title=root_title or service.name,
-        docs_url="/docs" if CURRENT_ENVIRONMENT == LOCAL_ENV else None,
-        redoc_url="/redoc" if CURRENT_ENVIRONMENT == LOCAL_ENV else None,
-        openapi_url="/openapi.json" if CURRENT_ENVIRONMENT == LOCAL_ENV else None,
+        docs_url="/docs",
+        redoc_url="/redoc",
+        openapi_url="/openapi.json",
         version=service.release,
     )
 
     _setup_cors(parent, public_cors_origins)
-
     parent.add_middleware(CatchAllExceptionMiddleware)
     register_error_handlers(parent)
 
@@ -162,43 +161,41 @@ def setup_service_api(
         parent.mount(mount_path, child, name=spec.tag.strip("/"))
         _set_servers(child, spec.public_base_url, mount_path)
 
-    if CURRENT_ENVIRONMENT in (LOCAL_ENV, DEV_ENV):
+    @parent.get("/", include_in_schema=False)
+    def index():
+        cards: list[CardSpec] = []
 
-        @parent.get("/", include_in_schema=False)
-        def index():
-            cards: list[CardSpec] = []
+        # Root card first
+        cards.append(
+            CardSpec(
+                tag="",  # renders as "/"
+                docs=DocTargets(
+                    swagger="/docs",
+                    redoc="/redoc",
+                    openapi_json="/openapi.json",
+                ),
+            )
+        )
 
-            # Root card first
+        # One card per version
+        for spec in versions:
+            tag = spec.tag.strip("/")
             cards.append(
                 CardSpec(
-                    tag="",  # renders as "/"
+                    tag=tag,
                     docs=DocTargets(
-                        swagger="/docs",
-                        redoc="/redoc",
-                        openapi_json="/openapi.json",
+                        swagger=f"/{tag}/docs",
+                        redoc=f"/{tag}/redoc",
+                        openapi_json=f"/{tag}/openapi.json",
                     ),
                 )
             )
 
-            # One card per version
-            for spec in versions:
-                tag = spec.tag.strip("/")
-                cards.append(
-                    CardSpec(
-                        tag=tag,
-                        docs=DocTargets(
-                            swagger=f"/{tag}/docs",
-                            redoc=f"/{tag}/redoc",
-                            openapi_json=f"/{tag}/openapi.json",
-                        ),
-                    )
-                )
-
-            html = render_index_html(
-                service_name=service.name,
-                release=service.release,
-                cards=cards,
-            )
-            return HTMLResponse(html)
+        html = render_index_html(
+            service_name=service.name,
+            release=service.release,
+            cards=cards,
+        )
+        return HTMLResponse(html)
 
     return parent
